Method: ResolveHelper#render_section

Defined in:
app/helpers/resolve_helper.rb

#render_section(arguments = {}) ⇒ Object

Will render an Umlaut HTML section. See SectionRenderer. Argument can be:

  1. An already initialized SectionRenderer

  2. :id => X, will load Section description hash from the resolve_sections configuration, finding description hash with :div_id == X.

  3. A complete section description hash. Ordinarily only used when that complete hash was previously looked up from resolve_sections config.

For documentation of possible values in the section descripton hash, see SectionRenderer.



28
29
30
31
32
# File 'app/helpers/resolve_helper.rb', line 28

def render_section(arguments = {})
  presenter = (arguments.kind_of?( SectionRenderer )) ?
    arguments : SectionRenderer.new(@user_request, arguments  )
  render(:partial => "section_display", :locals => {:presenter => presenter })
end